@@ -1,14 +1,10 @@
 __all__ = ['Query', 'Mutation', 'Subscription']
 import strawberry
 
+from .mutation import Mutation
 from .query import Query
 
 
-@strawberry.type
-class Mutation:
-    pass
-
-
 @strawberry.type
 class Subscription:
     pass
